# {{ full_model.name }}

## Project setup

### REQUIREMENTS

- python (3.x recommended) & pip (>= 22 recommended)

#### Install the dependencies

```sh
$ pip install - requirements.txt
```

#### create the migration for the project

```sh
$ python manage.py makemigrations
```

#### apply the migrations

```sh
$ python manage.py migrate
```

##### start the server

```sh
$ python manage.py runserver
```
