from django.urls import path
from .views import (
    {%- for mod in full_model.models %}
    {%- if mod.name != "User" %}
    {{mod.name}}ListApiView,
    {{mod.name}}DetailApiView,
    {%- endif -%}
    {%- endfor %}
)

urlpatterns = [
    {%- for mod in full_model.models %}
    {%- if mod.name != "User" %}
    path("{{mod.name.lower()}}s", {{mod.name}}ListApiView.as_view()),
    path("{{mod.name.lower()}}s/<int:{{mod.name.lower()}}_id>/", {{mod.name}}DetailApiView.as_view()),
    {%- endif -%}
    {%- endfor %}
]
