from django.contrib import admin
from django.urls import path, include
from {{full_model.name.lower()}} import urls as {{full_model.name.lower()}}_urls

urlpatterns = [
    path("admin/", admin.site.urls),
    path("api-auth/", include("rest_framework.urls")),
    path("api/", include({{full_model.name.lower()}}_urls)),
]
