# {{ full_model.name }}

## Project setup

### REQUIREMENTS

- python (3.x recommended) & pip (>= 22 recommended)

### HOW TO SET UP

Put appropriate parameters inside .env

#### Install Deps

```sh
$ pip install -r requirements.txt
```

##### RUN THE SERVER

```sh
$ python server.py
```
