Flask==2.2.5
Flask-Bcrypt==1.0.1
Flask-Login==0.5.0
Flask-Migrate==3.1.0
Flask-RESTful==0.3.9
Flask-SQLAlchemy==3.0.2
Flask-Cors==3.0.10
Flask-JWT-Extended==4.3.1
Werkzeug==2.2.2
python-dotenv==0.21.0
